#!/bin/sh
# -*- tab-width:  4 -*- ;; Emacs
# vi: set tabstop=4     :: Vi/ViM
############################################################ COPYRIGHT
#
# (c)2011. Devin Teske. All Rights Reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#
############################################################ GLOBALS

#
# Global exit status variables
#
SUCCESS=0
FAILURE=1

#
# Program name
#
progname="${0##*/}"

#
# OS Glue
#
UNAME_S=$( uname -s )
UNAME_R=$( uname -r )

############################################################ FUNCTIONS

# fprintf $fd $fmt [ $opts ... ]
#
# Like printf, except allows you to print to a specific file-descriptor. Useful
# for printing to stderr (fd=2) or some other known file-descriptor.
#
fprintf()
{
	local fd=$1
	[ $# -gt 1 ] || return $FAILURE
	shift 1
	printf "$@" >&$fd
}

# eprintf $fmt [ $opts ... ]
#
# Print a message to stderr (fd=2).
#
eprintf()
{
	fprintf 2 "$@"
}

# die [ $fmt [ $opts ... ]]
#
# Optionally print a message to stderr before exiting with failure status.
#
die()
{
	local fmt="$1"
	[ $# -gt 0 ] && shift 1
	[  "$fmt"  ] && eprintf "$fmt\n" "$@"

	exit $FAILURE
}

# usage
#
# Prints a short syntax statement and exits.
#
usage()
{
	local argfmt1="\t%s\n" argfmt2="\t\t%s\n"
	local optfmt="\t%-6s%s\n"
	local exfmt="\t%s\n"

	local device="cd0"
	case "$UNAME_S" in
	Linux) device="cdwriter";;
	FreeBSD)
		case "$UNAME_R" in
		4.*) device="rcd0c"
		esac
	esac

	eprintf "Usage: %s [OPTIONS] path_to_iso device_name\n" "$progname"

	eprintf "ARGUMENTS:\n"
	eprintf "$argfmt1" "path_to_iso"
	eprintf "$argfmt2" \
	        "Location of ISO file (either relative or absolute) to be"
	eprintf "$argfmt2" \
	        "written to DVD-ROM. [Required]"
	eprintf "\n"
	eprintf "$argfmt1" "device_name"
	eprintf "$argfmt2" \
	        "Device name (or path) of DVD-R/RW burner device (e.g.,"
	eprintf "$argfmt2" \
	        "\`$device' or \`/dev/$device') to write to. [Required]"
	eprintf "\n"

	eprintf "OPTIONS:\n"
	eprintf "$optfmt" "-h" \
	        "Print this message to stderr and exit."
	eprintf "\n"

	eprintf "EXAMPLE:\n"
	eprintf "$exfmt" \
	        "./$progname Druid-X.Y.iso $device"
	eprintf "\n"

	die
}

# eval2 $cmd ...
#
# Print a command to stdout before executing it.
#
eval2()
{
	echo "$*"
	eval "$@"
}

############################################################ MAIN SOURCE

[ $# -eq 2 ] || usage

ISOFILE="$1"
DVDDEV="$2"

case "$DVDDEV" in
*/*) : nothing to change;;
*)
	[ "$DVDDEV" -a -e "/dev/$DVDDEV" ] && DVDDEV="/dev/$DVDDEV"
esac

#
# Allow growisofs(1) to operate [safely] under sudo(8)
#
unset SUDO_COMMAND
export PATH="/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin"

echo "Copying data from: ${ISOFILE##*/}"
echo "...to destination: $DVDDEV"
echo ""
echo -n "Command: "
eval2 growisofs -dvd-compat -Z "$DVDDEV"="$ISOFILE" \&
pid=$!
echo "Process-id: $pid"

trap "kill -9 $pid" INT
wait $pid

################################################################################
# END
################################################################################
#
# $Header: /cvsroot/druidbsd/druidbsd/druid/src/tools/iso2dvd.sh,v 1.1 2012/01/28 07:01:43 devinteske Exp $
#
# $Copyright: 1999-2011 Vicor Inc. All rights reserved. $
#
# $Log: iso2dvd.sh,v $
# Revision 1.1  2012/01/28 07:01:43  devinteske
# Commit initial public beta release (beta 56)
#
# Revision 1.1  2012/01/26 17:26:26  dteske
# repocopy druid -> druid9
#
# Revision 1.3  2011/12/20 20:07:50  dteske
# Show proper sample device-name on FreeBSD-4.x
#
# Revision 1.2  2011/12/20 18:38:49  dteske
# Fix Ctrl-C bug and remove unused functions.
#
# Revision 1.1  2011/10/25 18:51:03  dteske
# Add iso2dvd utility script.
#
#
################################################################################
